@@ -80,7 +80,8 @@ def test_import_localtime():
     struct = fake_localtime_function()
     assert struct.tm_year == 2012
     assert struct.tm_mon == 1
-    assert struct.tm_mday == 14
+    assert struct.tm_mday >= 13  # eg. GMT+14
+    assert struct.tm_mday <= 15  # eg. GMT-14
 
 
 @freeze_time("2012-01-14 12:00:00")
@@ -144,3 +145,9 @@ def test_import_after_start():
     assert another_module.get_fake_localtime() is FakeLocalTime
     assert another_module.get_fake_gmtime() is FakeGMTTime
     assert another_module.get_fake_strftime() is FakeStrfTime
+
+
+def test_none_as_initial():
+    with freeze_time() as ft:
+        ft.move_to('2012-01-14')
+        assert fake_strftime_function() == '2012'
