@@ -137,6 +137,22 @@ def test_manual_increment():
         assert frozen_datetime() == initial_datetime
 
 
+def test_move_to():
+    initial_datetime = datetime.datetime(year=1, month=7, day=12,
+                                        hour=15, minute=6, second=3)
+
+    other_datetime = datetime.datetime(year=2, month=8, day=13,
+                                        hour=14, minute=5, second=0)
+    with freeze_time(initial_datetime) as frozen_datetime:
+        assert frozen_datetime() == initial_datetime
+
+        frozen_datetime.move_to(other_datetime)
+        assert frozen_datetime() == other_datetime
+
+        frozen_datetime.move_to(initial_datetime)
+        assert frozen_datetime() == initial_datetime
+
+
 def test_bad_time_argument():
     try:
         freeze_time("2012-13-14", tz_offset=-4)
@@ -442,6 +458,28 @@ class FrozenInheritedTests(BaseInheritanceFreezableTests):
         self.assertEqual(datetime.date(2013, 4, 9), datetime.date.today())
 
 
+class TestOldStyleClasses:
+    def test_direct_method(self):
+        # Make sure old style classes (not inheriting from object) is supported
+        @freeze_time('2013-04-09')
+        class OldStyleClass:
+            def method(self):
+                return datetime.date.today()
+
+        assert OldStyleClass().method() == datetime.date(2013, 4, 9)
+
+    def test_inherited_method(self):
+        class OldStyleBaseClass:
+            def inherited_method(self):
+                return datetime.date.today()
+
+        @freeze_time('2013-04-09')
+        class OldStyleClass(OldStyleBaseClass):
+            pass
+
+        assert OldStyleClass().inherited_method() == datetime.date(2013, 4, 9)
+
+
 def test_min_and_max():
     freezer = freeze_time("2012-01-14")
     real_datetime = datetime.datetime
